use role {role};
use warehouse {warehouse};
use database {database};
use schema {schema};

put file://{path} @{name} auto_compress=false parallel={parallel} overwrite={overwrite};
